<?php
/**
 * Class to register Latest news style 1
 *
 * @since 1.0.0
 *
 * @package Gutenbiz Blog
 */

class Gutenbiz_Blog_Latest_News_Style_First_Widget extends Gutenbiz_Blog_Base_Widget{

	/**
	 * make needed options for widget
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Gutenbiz Blog
	 */

	public function __construct(){

		parent::__construct( 
			'latest_news_style_one',
			esc_html__( 'RT: Latest News', 'gutenbiz-blog' )
		);

		$this->fields = array(
			'gutenbiz_lns1_title'=>array(
				'label'   => esc_html__( 'Title', 'gutenbiz-blog' ),
				'type'    => 'text',
				'default' => ''
			),
			'gutenbiz_lns1_select_cat'=>array(
				'label'   => esc_html__( 'Select Category', 'gutenbiz-blog' ),
				'type'    => 'multi-select',
				'choices' => Gutenbiz_Blog_Theme::get_categories_list(),
				'description' => esc_html( 'Hold down the Ctrl (windows) or Command (Mac) button to select multiple options.', 'gutenbiz-blog' ),
				'default' => array( '1' )
			),
			'gutenbiz_lns1_num_post'=>array(
				'label'   => esc_html__( 'Number Of Post To Display', 'gutenbiz-blog' ),
				'type'    => 'number',
				'default' => 4
			),
			'gutenbiz_lns1_excerpt'=>array(
				'label'   => esc_html__( 'Enable Excerpt', 'gutenbiz-blog' ),
				'type'    => 'checkbox',
				'default' => 1
			),
			'gutenbiz_lns1_excerpt_length'=>array(
				'label'   => esc_html__( 'Excerpt Length', 'gutenbiz-blog' ),
				'type'    => 'number',
				'default' => 10
			),
		);
	}

	/**
	 * Markup for widget
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public function widget( $args, $instance ){
		echo $args[ 'before_widget' ];
		
		$instance = $this->init_defaults( $instance );

		$active_post = Gutenbiz_Blog_Theme::get_posts_by_type( 'category', $instance[ 'gutenbiz_lns1_select_cat' ], $instance[ 'gutenbiz_lns1_num_post' ] );
		if( '' != $instance[ 'gutenbiz_lns1_title' ] ){ ?>
			<h2 class="widget-title gutenbiz-widget-title"><?php echo esc_html( $instance[ 'gutenbiz_lns1_title' ] ); ?></h2>
		<?php }
		if( !empty( $active_post ) ){?>
			<section class="gutenbiz-latest-news-style-one">
				<?php foreach( $active_post as $k => $p ){
					echo $k == 1 ? '<div class="gutenbiz-latest-news-small-wrapper">' : '';

					if( $k == 0 ){ ?>
						<div class="gutenbiz-style-one-bigger">
							<div class="gutenbiz-style-one-bigger-inner" style="background-image: url( '<?php echo esc_url( get_the_post_thumbnail_url( $p ) ); ?>') , url('<?php echo esc_url( Gutenbiz_Helper::get_theme_uri( 'assets/img/default-image.jpg' ) ); ?>' )">
								<div class="gutenbiz-style-one-bigger-inner-content">
									<?php $this->get_widget_category( $p, $instance ); ?>
										<h2><a href="<?php echo esc_url( get_the_permalink( $p ) );?>"><?php echo esc_html( get_the_title( $p ) ); ?></a></h2>
										<?php $this->get_widget_excerpt( $p, $instance );
										Gutenbiz_Blog_Theme::the_date( $p );
										Gutenbiz_Helper::posted_by();
									?>
								</div>
							</div>
						</div>
					<?php }else{ ?>
						<div class="gutenbiz-latest-news-small">
							<div class="gutenbiz-latest-news-small-inner">
								<div class="thumbnails">
									<a href="<?php echo esc_url( get_the_permalink( $p ) );?>"><img src="<?php echo esc_url( get_the_post_thumbnail_url( $p, 'thumbnail' ) ); ?>"></a>
								</div>
								<div class="gutenbiz-latest-news-small-content">
									<h2><a href="<?php echo esc_url( get_the_permalink( $p ) );?>"><?php echo esc_html( get_the_title( $p ) ); ?> </a></h2>
									<?php $this->get_widget_category( $p, $instance );
									$this->get_widget_excerpt( $p, $instance ); ?>
								</div>
							</div>
						</div>
					<?php }
					echo $k == count( $active_post ) - 1 ? '</div>' : '';
				} ?>
			</section>
		<?php }
		echo $args[ 'after_widget' ];
	}

	public function get_widget_excerpt( $post_id, $instance ){
		if( $instance[ 'gutenbiz_lns1_excerpt' ] ){ ?>
			<p class="feature-news-content gutenbiz-content"><?php echo gutenbiz_blog_excerpt( $instance[ 'gutenbiz_lns1_excerpt_length' ] , false, '...', $post_id ); ?></p>
		<?php }
	}

	public function get_widget_category( $post_id, $instance ){
		Gutenbiz_Helper::the_category( $post_id );
	}
}