<?php
/**
 * Gutenbiz Blog functions and definitions
 * Gutenbiz Blog only works in WordPress 4.7 or later.
 *
 * @link https://developer.wordpress.org/themes/advanced-topics/child-themes/
 * @package Gutenbiz Blog
 */
final class Gutenbiz_Blog_Theme{
	public function __construct(){
		# enqueue script
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'scripts' ) );

		# register the header area
		add_action( 'widgets_init', array( __CLASS__ , 'header_area' ) );

		# header above section
		add_action(  'gutenbiz_before_header', array( __CLASS__, 'header_before' ), 0 );

		# header above section
		add_action(  'gutenbiz_after_header', array( __CLASS__, 'header_after' ), 60 );

		# before footer on home page
		add_action(  'gutenbiz_footer', array( __CLASS__, 'before_footer' ) );

		# action after theme
		add_action( 'after_setup_theme', array( __CLASS__, 'after_parent_theme' ) );

		# widget init
		add_action( 'widgets_init', array( __CLASS__, 'register_widget' ) );

		# adds class on body to customize blog layouts
		add_filter( 'body_class' , array( __CLASS__ , 'add_body_classes' ) );

		# footer featured news
		add_action(  'gutenbiz_footer', array( __CLASS__, 'footer_featured_news' ) );

		# add scroll to top up button
		add_action( 'wp_footer', array( __CLASS__, 'add_scroll_to_top_button' ) );
	}

	/**
	 * Add scroll to top button on footer
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function add_scroll_to_top_button(){
		$enable = gutenbiz_get( 'scroll-to-top' );
		if( !$enable ){
			return;
		}?>
		<div class="gutenbiz-blog-scroll-to-top">
			<i class="fa fa-arrow-up"></i>
		</div>
	<?php }

	/**
	 * Get footer featured news
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 * @return object
	 *
	 * @package Gutenbiz Blog
	 */
	public static function footer_featured_news(){
		if( is_archive() || is_search() || is_single() || !gutenbiz_get( 'enable-footer-featured-news' ) ){
			return;
		}

		get_template_part( 'templates/footer/footer-featured', 'news' );
	}

	/**
	* Enqueue styles and scripts
	*
	* @static
	* @access public
	* @since  1.0.0
	*
	* @package Gutenbiz Blog
	*/
	public static function scripts(){
		$scripts = array(
			# enqueue parent stylesheet
			array(
				'handler'  => 'gutenbiz-blog',
				'style'    => get_template_directory_uri() . '/style.css',
				'version'  => wp_get_theme()->get('Version'),
				'absolute' => true,
				'minified' => false
			),
			array(
		        'handler' => 'slick-script',
		        'script'  => 'assets/js/slick.js',
		    ),
			array(
				'handler' => 'slick-style',
				'style'  => 'assets/css/slick.css',
			),

			array(
			    'handler' => 'jquery-sticky',
			    'script'  => 'assets/js/jquery.sticky.js',
			    'minified' => false
			),
			array(
			    'handler' => 'gutenbiz-blog-script',
			    'script'  => 'assets/js/script.js',
			    'minified' => false
			),
		);
		Gutenbiz_Helper::enqueue( $scripts );
	}

	/**
	 * Register Header Area in theme 
	 *
	 * @static
	 * @access public
	 * @return object
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function header_area(){
		register_sidebar( array(
	        'name' 			=> esc_html__( 'Before Header Widget Area', 'gutenbiz-blog' ),
	        'id' 			=> Gutenbiz_Helper::fn_prefix( 'header_before' ),
	        'description' 	=> esc_html__( 'Widgets in this area will be shown above the header', 'gutenbiz-blog' ),
	        'before_widget' => '<div id="%1$s" class="widget %2$s extra-widget-area container">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h2 class="widget-title">',
	        'after_title'   => '</h2>',
		));

		register_sidebar( array(
	        'name' 			=> esc_html__( 'After Header Widget Area', 'gutenbiz-blog' ),
	        'id' 			=> Gutenbiz_Helper::fn_prefix( 'header_after' ),
	        'description' 	=> esc_html__( 'Widgets in this area will be shown after the header', 'gutenbiz-blog' ),
	        'before_widget' => '<div id="%1$s" class="widget %2$s  extra-widget-area container">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h2 class="widget-title">',
	        'after_title'   => '</h2>',
		));

		register_sidebar( array(
	        'name' 			=> esc_html__( 'Before Footer Widget Area', 'gutenbiz-blog' ),
	        'id' 			=> Gutenbiz_Helper::fn_prefix( 'before_footer' ),
	        'description' 	=> esc_html__( 'Widgets in this area will be shown before footer.', 'gutenbiz-blog' ),
	        'before_widget' => '<div id="%1$s" class="widget %2$s  extra-widget-area container">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h2 class="widget-title">',
	        'after_title'   => '</h2>',
		));
	}

	/**
	 * Header before area
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function header_before(){
		if( is_home() || is_front_page() ){			
			if( is_active_sidebar( Gutenbiz_Helper::fn_prefix( 'header_before' ) ) ){
				dynamic_sidebar( Gutenbiz_Helper::fn_prefix( 'header_before' ) );
			}
		}
	}

	/**
	 * Header after area
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function header_after(){
		if( is_home() || is_front_page() ){		
			if( is_active_sidebar( Gutenbiz_Helper::fn_prefix( 'header_after' ) ) ){
				dynamic_sidebar( Gutenbiz_Helper::fn_prefix( 'header_after' ) );
			}
		}
	}

	/**
	 * Before footer
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function before_footer(){
		if( is_home() || is_front_page() ){			
			if( is_active_sidebar( Gutenbiz_Helper::fn_prefix( 'before_footer' ) ) ){
				dynamic_sidebar( Gutenbiz_Helper::fn_prefix( 'before_footer' ) );
			}
		}

		if( is_single() ){
			$related = get_posts( 
			    array( 
			        'category__in' => wp_get_post_categories( get_the_ID() ), 
			        'numberposts'  => 3, 
			        'post__not_in' => array( get_the_ID() ) 
			    ) 
			);
			if( $related ){		
				set_query_var('single_related_posts', $related );
				get_template_part( 'templates/single', 'related');
			}
		}
	}

	/**
	 * After parent theme
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function after_parent_theme(){
		# remove action to add extra options
		remove_action( 'init', 'gutenbiz_advanced_options' );

		# include custom control
		Gutenbiz_Helper::include( array(
			'cat-dropdown/cat-dropdown'
		), 'classes/custom-control', '');

		# include dynamic css
		Gutenbiz_Helper::include( array(
			'common'
		), 'includes/dynamic-css', '');

		# include options file
		Gutenbiz_Helper::include( array(
			'footer-missed-options',
			'advance-options'
		), 'includes/theme-options', '');

		Gutenbiz_Helper::include( array(
			'class-excerpt'
		), 'classes', '' );

		# widget files
		Gutenbiz_Helper::include( array(
			'class-base-widget',
			'class-post-with-thumbnail',
			'class-profile-card',
			'class-latest-news-style-1',
		), 'classes/widget', '' );

		# filter to modify priority
		add_filter( Gutenbiz_Helper::with_prefix( 'customizer_get_defaults','_' ), array( __CLASS__ , 'change_defaults' ), 99 ,2 );

		#filter to change default on admin
		add_filter( Gutenbiz_Helper::fn_prefix( 'customizer_get_setting_arg' ), array( __CLASS__, 'change_default_admmin' ), 10, 2 );
	}

	/**
	 * Change default value
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */	
	public static function change_defaults( $def, $instance ){
		$id = Gutenbiz_Helper::with_prefix( 'footer-copyright-text' );
		$per_row = Gutenbiz_Helper::with_prefix( 'post-per-row' );
		$sidebar = Gutenbiz_Helper::with_prefix( 'sidebar-position' );
		$primary_color = Gutenbiz_Helper::with_prefix( 'primary-color' );

		$def[ $id ] = esc_html__( 'Copyright &copy; 2021 | Gutenbiz Blog', 'gutenbiz-blog' );	
		$def[ $per_row ] = '1';
		$def[ $sidebar ] = 'right-sidebar';
		$def[ $primary_color ] = '#1672f4';

		return $def;
	}

	/**
	 * Change default value on admin
	 *
	 * @static
	 * @access public
	 * @since  1.0.1
	 *
	 * @package Gutenbiz Blog
	 */	
	public static function change_default_admmin( $args, $field ){
		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'footer-copyright-text' ) ){
			$args[ 'default' ] = esc_html__( 'Copyright &copy; 2021 | Gutenbiz Blog', 'gutenbiz-blog' );
		}

		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'post-per-row' ) ){
			$args[ 'default' ] = '1';
		}

		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'sidebar-position' ) ){
			$args[ 'default' ] = 'right-sidebar';
		}

		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'primary-color' ) ){
			$args[ 'default' ] = '#1672f4';
		}

		return $args;
	}

	/**
	 * register widget
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 * @return string
	 *
	 * @package Gutenbiz Blog
	 */
	public static function register_widget() {
		$st_widgets = array(
			'Gutenbiz_Blog_Post_With_Thumb_Widget',
			'Gutenbiz_Blog_Profile_Card_Widget',
			'Gutenbiz_Blog_Latest_News_Style_First_Widget'
		);
		foreach ( $st_widgets as $widget ) {			
			register_widget( $widget );
		}
	}

	/**
	 * returns users array
	 *
	 * @since 1.0.0
	 * @return array
	 *
	 * @package Gutenbiz Blog
	 */
	public static function get_users_list(){
		$users = get_users();
		$users_arr = array();
		foreach ( $users as $user ) {
			$users_arr[ $user->ID ] = ucfirst( $user->user_nicename );				
		}
		return $users_arr;
	}

	/**
	 * profile card template
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function the_profile_card( $author_id = false ){
		if( !$author_id ){
			return;
		}
		set_query_var( 'author_id', $author_id );
		get_template_part( 'templates/profile', 'card' );
	}

	/**
	 * adds class on body to customize blog layouts
	 *
	 * @static
	 * @access public
	 * @return object
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function add_body_classes( $classes ){
		if( gutenbiz_get( 'post-per-row' ) == '1' ){
			$classes[] = 'gutenbiz-blog-post-per-page-1';
		}

		if( gutenbiz_get( 'blog-sticky-header' ) ){
			$classes[] = 'gutenbiz-blog-sticky-header';
		}

		return $classes;
	}

	/**
	 * returns category array
	 *
	 * @since 1.0.0
	 * @return array
	 *
	 * @package Gutenbiz Blog
	 */
	public static function get_categories_list(){
		$cat_array = array( '0' => esc_html__( 'All', 'gutenbiz-blog' ) );
		$category = get_categories();
		foreach ( $category as $cat ) {
			$cat_array[ $cat->term_id ] = $cat->name;
		}
		return $cat_array;
	}

	/**
	 * Get according to type
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function get_posts_by_type( $type, $cat_id, $post_to_display = false ){

		$posts = array();
		if( 'latest' == $type ){
			$recent_posts = wp_get_recent_posts(array(
			    'numberposts' => $post_to_display ? $post_to_display : -1,
			    'post_status' => 'publish'
			));

			foreach ( $recent_posts as $post) {
				$posts[] = $post[ 'ID' ]; 
			}
		}elseif( 'category' == $type ){			
			$args = array(
				'post_type' => 'post',
				'posts_per_page' => $post_to_display ? $post_to_display : -1,
				'ignore_sticky_posts' => 1,
				'orderby' => 'date',
				'order' => 'DESC'
			);
			if( $cat_id ){
				$args[ 'cat' ] = $cat_id; 
			}

			$query = new WP_Query( $args );
			if ( $query->have_posts() ) {
			    while ( $query->have_posts() ) {
			        $query->the_post();
			        $posts[] = get_the_ID();
			    }
			}
			wp_reset_postdata();
		}
		if( empty( $posts ) ){
			return false;
		}else{
			return $posts;
		}
	}

	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function the_date( $post_id = null, $status = 'posted' ) {
		
		$show = apply_filters( Gutenbiz_Helper::fn_prefix( 'show_post_date' ), true );

		if( $show ):
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';

			if( $status == 'updated'){
				if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
					$time_string = '<time class="updated" datetime="%3$s">%4$s</time>';
				}				
			}

			$time_tag = sprintf(
				$time_string,
				esc_attr( get_the_date( DATE_W3C, $post_id ) ),
				esc_html( get_the_date( get_option('date_format'), $post_id ) ),
				esc_attr( get_the_modified_date( DATE_W3C, $post_id ) ),
				esc_html( get_the_modified_date( DATE_W3C, $post_id ) )
			);

			printf(
				'<span class="posted-on">
					%2$s 
					<a href="%1$s" rel="bookmark">
						%3$s
					</a>
				</span>',
				esc_url( Gutenbiz_Helper::get_day_link() ),
				( 'posted' == $status ) ? esc_html__( 'On', 'gutenbiz-blog' ) : esc_html__( 'Updated on', 'gutenbiz-blog' ),
				$time_tag
			);
		endif;
	}

	/**
	 * Prints the category of the posts
	 *
	 * @static
	 * @access public
	 * @return string
	 * @since  1.0.0
	 *
	 * @package Gutenbiz Blog
	 */
	public static function the_category( $post_id = false ){
		$show = apply_filters( Gutenbiz_Helper::fn_prefix( 'show_post_category' ), true );
		if( $show ){
			$cat = get_the_category( $post_id );
			if( !empty( $cat ) ){ ?>
				<ul class="post-categories">
					<?php foreach ( $cat as $c ) { ?>
						<li>
							<a href="<?php echo esc_url( get_category_link( $c ) ); ?>">
								<?php echo esc_html( $c->name ); ?>
							</a>
						</li>
					<?php }?>
				</ul>					
			<?php }
		}
	}
}

new Gutenbiz_Blog_Theme();